Vaulty
======

.. image:: https://travis-ci.org/crccheck/vaulty.svg?branch=master
    :target: https://travis-ci.org/crccheck/vaulty

A shell interface for browsing Hashicorp Vault

Supports:

* simple tab completion
* ``cat``
* ``cd``
* ``ls``
